/***************************************************************************
 *   Copyright (C) 2005 by Roberto Cappuccio                               *
 *   robertoc@dnet.it                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "dlgsearch.h"

#include <kapplication.h>
#include <klocale.h>
#include <qvariant.h>
#include <qsplitter.h>
#include <qtabwidget.h>
#include <qlabel.h>
#include <qbuttongroup.h>
#include <qcheckbox.h>
#include <kpushbutton.h>
#include <klineedit.h>
#include <kicondialog.h>
#include <ktextedit.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <qimage.h>
#include <qpixmap.h>
#include <qiconset.h>
#include <qvaluelist.h>

#include "dlgmainwindow.h"

using namespace std;

DlgSearch::DlgSearch( QWidget* parent, const char* name, WFlags fl )
    : QWidget( parent, name, fl )
{
    setCaption( i18n( "Kat" ) );

    // Button icon (22 pixels)
    QIconSet isSearchButton = createToolbarIconSet( "find" );

    if ( !name ) {
        setName( "Search" );
    }
    QGridLayout *SearchLayout = new QGridLayout( this, 1, 1, 4, 4, "SearchLayout");

    splitter15 = new QSplitter( this, "splitter15" );
    splitter15->setOrientation( QSplitter::Vertical );

    splitter14 = new QSplitter( splitter15, "splitter14" );
    splitter14->setOrientation( QSplitter::Horizontal );

    SearchSetup = new QTabWidget( splitter14, "SearchSetup" );

    tab = new QWidget( SearchSetup, "tab" );

    tlSearch = new QLabel( tab, "tlSearch" );
    tlSearch->setGeometry( QRect( 10, 10, 70, 21 ) );

    bgSearchParameters = new QButtonGroup( tab, "bgSearchParameters" );
    bgSearchParameters->setGeometry( QRect( 12, 46, 500, 130 ) );

    cbFilenames = new QCheckBox( bgSearchParameters, "cbFilenames" );
    cbFilenames->setGeometry( QRect( 20, 30, 200, 20 ) );
    cbFilenames->setChecked( TRUE );

    cbDescriptions = new QCheckBox( bgSearchParameters, "cbDescriptions" );
    cbDescriptions->setGeometry( QRect( 20, 60, 200, 20 ) );
    cbDescriptions->setChecked( TRUE );

    cbFullTexts = new QCheckBox( bgSearchParameters, "cbFullTexts" );
    cbFullTexts->setGeometry( QRect( 20, 90, 200, 20 ) );
    cbFullTexts->setChecked( TRUE );

    pbLimitSimpleSearch = new KPushButton( tab, "pbLimitSimpleSearch" );
    pbLimitSimpleSearch->setGeometry( QRect( 530, 70, 120, 30 ) );
    pbLimitSimpleSearch->setEnabled( false );

    pbConfigureSimple = new KPushButton( tab, "pbConfigureSimple" );
    pbConfigureSimple->setGeometry( QRect( 530, 100, 120, 30 ) );
    pbConfigureSimple->setEnabled( false );

    leSearchText = new KLineEdit( tab, "leSearchText" );
    leSearchText->setGeometry( QRect( 90, 10, 420, 20 ) );

    ibStartSimpleSearch = new KPushButton( tab, "ibStartSimpleSearch" );
    ibStartSimpleSearch->setGeometry( QRect( 530, 10, 120, 60 ) );
    ibStartSimpleSearch->setIconSet( isSearchButton );
    ibStartSimpleSearch->setEnabled( true );

    pbCloseSimple = new KPushButton( tab, "pbCloseSimple" );
    pbCloseSimple->setGeometry( QRect( 530, 150, 120, 30 ) );
    pbCloseSimple->setEnabled( false );

    SearchSetup->insertTab( tab, QString( "" ) );

    tab_2 = new QWidget( SearchSetup, "tab_2" );
    tab_2->setEnabled( false );

    pbLimitAdvancedSearch = new KPushButton( tab_2, "pbLimitAdvancedSearch" );
    pbLimitAdvancedSearch->setGeometry( QRect( 530, 70, 120, 30 ) );

    pbCloseAdvanced = new KPushButton( tab_2, "pbCloseAdvanced" );
    pbCloseAdvanced->setGeometry( QRect( 530, 150, 120, 30 ) );

    pbOptions = new KPushButton( tab_2, "pbOptions" );
    pbOptions->setGeometry( QRect( 402, 149, 111, 31 ) );

    pbValidate = new KPushButton( tab_2, "pbValidate" );
    pbValidate->setGeometry( QRect( 400, 70, 111, 31 ) );

    pbModify = new KPushButton( tab_2, "pbModify" );
    pbModify->setGeometry( QRect( 400, 40, 111, 31 ) );

    pbAnd = new KPushButton( tab_2, "pbAnd" );
    pbAnd->setGeometry( QRect( 10, 150, 76, 30 ) );

    pbOr = new KPushButton( tab_2, "pbOr" );
    pbOr->setGeometry( QRect( 90, 150, 76, 30 ) );

    pbXor = new KPushButton( tab_2, "pbXor" );
    pbXor->setGeometry( QRect( 170, 150, 76, 30 ) );

    pbNot = new KPushButton( tab_2, "pbNot" );
    pbNot->setGeometry( QRect( 250, 150, 76, 30 ) );

    pbParenthesisOpen = new KPushButton( tab_2, "pbParenthesisOpen" );
    pbParenthesisOpen->setGeometry( QRect( 330, 150, 30, 30 ) );

    pbParenthesisClose = new KPushButton( tab_2, "pbParenthesisClose" );
    pbParenthesisClose->setGeometry( QRect( 360, 150, 30, 30 ) );

    teCriteria = new KTextEdit( tab_2, "teCriteria" );
    teCriteria->setGeometry( QRect( 10, 10, 380, 140 ) );

    pbConfigureAdvanced = new KPushButton( tab_2, "pbConfigureAdvanced" );
    pbConfigureAdvanced->setGeometry( QRect( 530, 100, 120, 30 ) );

    ibStartAdvancedSearch = new KPushButton( tab_2, "ibStartAdvancedSearch" );
    ibStartAdvancedSearch->setGeometry( QRect( 530, 10, 120, 60 ) );
    ibStartAdvancedSearch->setIconSet( isSearchButton );
    ibStartAdvancedSearch->setEnabled( true );

    pbInsert = new KPushButton( tab_2, "pbInsert" );
    pbInsert->setGeometry( QRect( 400, 10, 111, 31 ) );
    SearchSetup->insertTab( tab_2, QString("") );

    SearchLayout->addWidget( splitter15, 0, 0 );
    languageChange();
    resize( QSize(802, 301).expandedTo(minimumSizeHint()) );
    clearWState( WState_Polished );

    // signals and slots connections
    connect( ibStartSimpleSearch, SIGNAL( clicked() ),
             this, SLOT( simpleStartSearch() ) );
    connect( pbLimitSimpleSearch, SIGNAL( clicked() ),
             this, SLOT( simpleLimitSearch() ) );
    connect( pbConfigureSimple, SIGNAL( clicked() ),
             this, SLOT( simpleConfigure() ) );
    connect( pbCloseSimple, SIGNAL( clicked() ),
             this, SLOT( simpleClose() ) );
    connect( ibStartAdvancedSearch, SIGNAL( clicked() ),
             this, SLOT( advancedStartSearch() ) );
    connect( pbLimitAdvancedSearch, SIGNAL( clicked() ),
             this, SLOT( advancedLimitSearch() ) );
    connect( pbConfigureAdvanced, SIGNAL( clicked() ),
             this, SLOT( advancedConfigure() ) );
    connect( pbCloseAdvanced, SIGNAL( clicked() ),
             this, SLOT( advancedClose() ) );
    connect( pbNot, SIGNAL( clicked() ),
             this, SLOT( criteriaNot() ) );
    connect( pbXor, SIGNAL( clicked() ),
             this, SLOT( criteriaXor() ) );
    connect( pbAnd, SIGNAL( clicked() ),
             this, SLOT( criteriaAnd() ) );
    connect( pbInsert, SIGNAL( clicked() ),
             this, SLOT( criteriaInsert() ) );
    connect( pbModify, SIGNAL( clicked() ),
             this, SLOT( criteriaModify() ) );
    connect( pbOr, SIGNAL( clicked() ),
             this, SLOT( criteriaOr() ) );
    connect( pbParenthesisOpen, SIGNAL( clicked() ),
             this, SLOT( criteriaParenthesisOpen() ) );
    connect( pbParenthesisClose, SIGNAL( clicked() ),
             this, SLOT( criteriaParenthesisClose() ) );
    connect( pbValidate, SIGNAL( clicked() ),
             this, SLOT( criteriaValidate() ) );
    connect( pbOptions, SIGNAL( clicked() ),
             this, SLOT( criteriaOptions() ) );
    connect( leSearchText, SIGNAL( returnPressed () ),
             this, SLOT( simpleStartSearch() ) );
    connect( leSearchText, SIGNAL( textChanged ( const QString & ) ),
             this, SLOT( slotTextChanged(const QString & ) ) );
    slotTextChanged(  leSearchText->text() );
}

DlgSearch::~DlgSearch() {
}

void DlgSearch::slotTextChanged(const QString &_text )
{
    ibStartSimpleSearch->setEnabled( !_text.isEmpty() );
}

void DlgSearch::languageChange() {
    tlSearch->setText( i18n( "Search" ) );
    bgSearchParameters->setTitle( i18n( "Parameters" ) );
    cbFilenames->setText( i18n( "Search in file names" ) );
    cbDescriptions->setText( i18n( "Search in metadata" ) );
    cbFullTexts->setText( i18n( "Search in fulltexts" ) );
    pbLimitSimpleSearch->setText( i18n( "Limit search" ) );
    pbConfigureSimple->setText( i18n( "Configure" ) );
    ibStartSimpleSearch->setText( i18n( "Search" ) );
    pbCloseSimple->setText( i18n( "Close" ) );
    SearchSetup->changeTab( tab, i18n( "Simple search" ) );
    pbLimitAdvancedSearch->setText( i18n( "Limit search" ) );
    pbCloseAdvanced->setText( i18n( "Close" ) );
    pbOptions->setText( i18n( "Options" ) );
    pbValidate->setText( i18n( "Validate" ) );
    pbModify->setText( i18n( "Modify" ) );
    pbAnd->setText( i18n( "AND" ) );
    pbOr->setText( i18n( "OR" ) );
    pbXor->setText( i18n( "XOR" ) );
    pbNot->setText( i18n( "NOT" ) );
    pbParenthesisOpen->setText( i18n( "(" ) );
    pbParenthesisClose->setText( i18n( ")" ) );
    pbConfigureAdvanced->setText( i18n( "Configure" ) );
    ibStartAdvancedSearch->setText( i18n( "Search" ) );
    pbInsert->setText( i18n( "Insert" ) );
    SearchSetup->changeTab( tab_2, i18n( "Advanced search" ) );
}

void DlgSearch::simpleStartSearch() {
    QValueList<int> results;
    bool filenames;
    bool descriptions;
    bool fulltexts;

    filenames = cbFilenames->isChecked();
    descriptions = cbDescriptions->isChecked();
    fulltexts = cbFullTexts->isChecked();
    DlgMainWindow* mf = (DlgMainWindow*)kapp->mainWidget();

    results = mf->databaseManager()->doSearch( leSearchText->text(), filenames, descriptions, fulltexts );

    mf->populateSearchViews( results );
}

void DlgSearch::simpleLimitSearch() {
}

void DlgSearch::simpleConfigure() {
}

void DlgSearch::advancedStartSearch() {
}

void DlgSearch::criteriaAnd() {
}

void DlgSearch::criteriaOr() {
}

void DlgSearch::criteriaXor() {
}

void DlgSearch::criteriaNot() {
}

void DlgSearch::criteriaParenthesisOpen() {
}

void DlgSearch::criteriaParenthesisClose() {
}

void DlgSearch::criteriaInsert() {
}

void DlgSearch::criteriaModify() {
}

void DlgSearch::criteriaValidate() {
}

void DlgSearch::advancedLimitSearch() {
}

void DlgSearch::advancedConfigure() {
}

void DlgSearch::advancedClose() {
}

void DlgSearch::criteriaOptions() {
}

void DlgSearch::simpleClose() {
}


#include "dlgsearch.moc"
