/***************************************************************************
 *   Copyright (C) 2005 by Roberto Cappuccio                               *
 *   robertoc@dnet.it                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <kdialogbase.h>
#include <kmessagebox.h>
#include <klocale.h>
#include <qvariant.h>
#include <qsplitter.h>
#include <qtextedit.h>
#include <qpushbutton.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <kfiledialog.h>
#include <kstdguiitem.h>
#include <qvbox.h>
#include "dlgshowfulltext.h"
#include "kat.h"
#include "katdatabasemanager.h"
#include "dlgmainwindow.h"

DlgShowFullText::DlgShowFullText( DlgMainWindow *_dm, long fileId, const char* name, bool modal, WFlags fl )
   : KDialogBase( _dm, name, modal, i18n( "Fulltext" ), KDialogBase::User1|KDialogBase::Cancel),
     dm( _dm )
{
    QVBox *page = makeVBoxMainWidget();

    teFullText = new QTextEdit( page, "teFullText" );

    setButtonText( KDialogBase::User1, KStdGuiItem::save().text() );

    resize( QSize(532, 297).expandedTo(minimumSizeHint()) );
    clearWState( WState_Polished );

    // signals and slots connections
    connect( this, SIGNAL( user1Clicked() ), this, SLOT( slotSave() ) );
    init(fileId);
}

DlgShowFullText::~DlgShowFullText() {
}

void DlgShowFullText::init( long fileId) {
    blobInfo bi = dm->databaseManager()->readFullTextRecord( fileId );
    QByteArray xba = bi.blobData;
    xba = qUncompress( xba );
    QString fullText( xba );

    teFullText->setText( fullText );
}

void DlgShowFullText::slotSave() {
    QString fn = KFileDialog::getSaveFileName( QString::null, "*.txt|"+i18n( "Text files (*.txt)" ), this ,
                                                i18n( "Specify location and filename for the text file" ));
    if ( !fn.isEmpty() ) {
        // save the text file
        bool m_open;
        QFile m_file( fn );
        QTextStream m_stream( &m_file );

        m_open = m_file.open( IO_WriteOnly );
        if (m_open) {
            m_stream << teFullText->text();
            m_file.close();

            KMessageBox::information( this, i18n( "The file has been successfully saved" ) );
        } else {
            KMessageBox::error( this, i18n( "The file cannot be created in the specified location" ) );
        }

    }
}

#include "dlgshowfulltext.moc"
