/*
 * text.c
 * Copyright (C) 1999-2004 A.J. van Os; Released under GNU GPL
 */

#include <string.h>
#include <malloc.h>
#include "antiword.h"

static encoding_type eEncoding = encoding_neutral;
static long lYtopCurr = 0;
static UCHAR ucNbsp = 0;

void vPrologueTXT(diagram_type *pDiag, const options_type *pOptions) {
	eEncoding = pOptions->eEncoding;
	pDiag->lXleft = 0;
	pDiag->lYtop = 0;
	lYtopCurr = 0;
}

void vEpilogueTXT(char *pOutBuffer) {
	strcat(pOutBuffer, "\n");
}

static void vPrintTXT(char *pOutBuffer, const char *szString, size_t tStringLength) {

	const UCHAR *ucBytes;

	if (szString == NULL || szString[0] == '\0' || tStringLength == 0) {
		return;
	}

	if (ucNbsp == 0) {
		ucNbsp = ucGetNbspCharacter();
	}

	ucBytes = (UCHAR *)szString;
	strcat(pOutBuffer, (char*)ucBytes);

}

static void vMoveTo(diagram_type *pDiag) {
	int	iCount, iNbr;

	if (pDiag->lYtop != lYtopCurr) {
		iNbr = iDrawUnits2Char(pDiag->lXleft);
		for (iCount = 0; iCount < iNbr; iCount++) {
            strcat(pDiag->szOutBuffer, " ");
		}
		lYtopCurr = pDiag->lYtop;
	}
}

void vMove2NextLineTXT(diagram_type *pDiag) {
	pDiag->lYtop++;
    strcat(pDiag->szOutBuffer, "\n");    
}

void vSubstringTXT(diagram_type *pDiag, const char *szString, size_t tStringLength, long lStringWidth) {
	if (szString[0] == '\0' || tStringLength == 0) {
		return;
	}

	vMoveTo(pDiag);
	vPrintTXT(pDiag->szOutBuffer, szString, tStringLength);
	pDiag->lXleft += lStringWidth;
}

void vStartOfParagraphTXT(diagram_type *pDiag, long lBeforeIndentation) {
	if (lBeforeIndentation >= lTwips2MilliPoints(HEADING_GAP)) {
		vMove2NextLineTXT(pDiag);
	}
}

 void vEndOfParagraphTXT(diagram_type *pDiag, long lAfterIndentation) {
	if (pDiag->lXleft > 0) {
		vMove2NextLineTXT(pDiag);
	}

	if (lAfterIndentation >= lTwips2MilliPoints(HEADING_GAP)) {
		vMove2NextLineTXT(pDiag);
	}
}

void vEndOfPageTXT(diagram_type *pDiag, long lAfterIndentation) {
	vEndOfParagraphTXT(pDiag, lAfterIndentation);
}
