/***************************************************************************
 *   Copyright (C) 2005 by Roberto Cappuccio                               *
 *   robertoc@dnet.it                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <kstandarddirs.h>
#include "kat_export.h"

#include <stdio.h>
#include <stdlib.h>
#include <stddef.h>
#include <string.h>
#include <sys/stat.h>
#include "fulltext_pdf.h"
#include <poppler-qt.h>
#include <kdebug.h>

extern "C"
{
    KAT_EXPORT FulltextExtractor *new_extractor( const QString& path ) {
        return new PDFExtractor( path );
    }
}

PDFExtractor::PDFExtractor( const QString &path ) :
    m_bDone( false ),
    m_path( path )
{
}

PDFExtractor::~PDFExtractor()
{
}

void PDFExtractor::extract( QString& data )
{
    kdDebug() << "PDFExtractor start" << endl;
    if ( m_bDone ) {
        data = QString::null;
        return;
    }
    m_bDone = true;

    Poppler::Document *doc = Poppler::Document::load(m_path.latin1());

    if ( !doc || doc->isLocked()) {
        delete doc;
        data = QString::null;
        return;
    }

    //kdDebug() << "PDFExtractor 1" << endl;

    QTextOStream stream( &data );
    stream << "<fulltext>";

    for ( int p = 1; p <= doc->getNumPages(); p++) {
        Poppler::Page *page;
        page = doc->getPage(p-1);
        stream << QString( "<page n=%1>" ).arg( p )
            << page->getText( 0L ).replace( "&", "&amp;" ).replace( "<", "&lt;" )
            << "</page>";
    }

    stream << "</fulltext>";

    delete doc;

    kdDebug() << "PDFExtractor end" << endl;
}

