/***************************************************************************
 *   Copyright (C) 2005 by Roberto Cappuccio                               *
 *   robertoc@dnet.it                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <kstandarddirs.h>
#include <kdebug.h>
#include <qregexp.h>

#include "fulltext_rtf.h"
#include "kat_export.h"

extern "C"
{
    KAT_EXPORT FulltextExtractor *new_extractor(const QString& path)
    {
        return new RTFExtractor(path);
    }
}

RTFExtractor::RTFExtractor(const QString &path) :
    m_file(path),
    m_stream(&m_file),
    m_bDone( false )
{
    m_open = m_file.open(IO_ReadOnly);
}

RTFExtractor::~RTFExtractor()
{
    m_file.close();
}

void RTFExtractor::extract(QString& data)
{
    kdDebug() << "RTFExtractor start" << endl;
    if ( m_bDone ) {
        data = QString::null;
        return;
    }
    m_bDone = true;

    if (m_open) {
        QString d = m_stream.read();

        d = d.replace( QChar( 10 ), " " );
        d = d.replace( QChar( 13 ), " " );

        // character codes in the 2 formats (hexadecimal and decimal)
        for ( int i=127; i <256; i++ ) {
            QString s;
            //kdDebug() << s.sprintf( "\\'%02x", i ) << " : " << QString( QChar( i ) ) << endl;

            d = d.replace( QRegExp( s.sprintf( "\\\\'%02x", i ) ), QString( QChar( i ) ) ); // (\'00)
            d = d.replace( QRegExp( s.sprintf( "\\\\u%d", i ) ), QString( QChar( i ) ) ); // (\u000)
        }

        d = d.replace( QRegExp( "\\{\\\\\\\\[^\\}]*\\}" ), " " ); // {\\image.png}
        d = d.replace( QRegExp( "\\{\\\\stylesheet[^#]*;\\}\\}" ), " " ); // {\stylesheet xxx {\s xxxx;}}
        d = d.replace( QRegExp( "\\{\\\\font[^#]*;\\}\\}" ), " " ); // {\font xxx {\f xxxx;}}
        d = d.replace( QRegExp( "\\{\\\\\\*[^;]*;\\}" ), " " ); // {\*something;}
        d = d.replace( QRegExp( "\\{\\\\comment[^;]*;\\}" ), " " );
        d = d.replace( QRegExp( "\\{\\\\listlevel[^;]*;\\}" ), " " );
        d = d.replace( QRegExp( "\\\\[^\\s]*\\s" ), " " );
        d = d.replace( QRegExp( "\\\\[^\\}]*\\}" ), " " );

        d = d.replace( QRegExp( "\\{" ), " " );
        d = d.replace( QRegExp( "\\}" ), " " );

        d = d.simplifyWhiteSpace(); // clean up white spaces

        QTextOStream stream( &data );
        stream << "<fulltext>";
        stream << d.local8Bit();
        stream << "</fulltext>";
    }
    kdDebug() << "RTFExtractor end" << endl;
}

