/***************************************************************************
 *   Copyright (C) 2005 by Roberto Cappuccio                               *
 *   robertoc@dnet.it                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <kapplication.h>
#include <kaboutdata.h>
#include <kcmdlineargs.h>
#include <klocale.h>

#include <time.h>
#include <dirent.h>
#include <sys/stat.h>
#include <qpixmap.h>
#include <ksplashscreen.h>
#include <kglobal.h>
#include <kstandarddirs.h>
#include <kurl.h>
#include <kio/job.h>
#include <kio/jobclasses.h>
#include <qguardedptr.h>
#include <qtimer.h>

#include "kat.h"
#include "kat_util.h"
#include "dlgmainwindow.h"
#include "katdatabasemanager.h"
#include "katlanguagemanager.h"

static const char description[] = I18N_NOOP( "KAT - Desktop Search Engine" );
static const char version[] = "0.5.3";

static KCmdLineOptions options[] = {
  { "+[URL]", I18N_NOOP( "Document to open" ), 0 },
    KCmdLineLastOption
};

int main( int argc, char **argv ) {

    KAboutData about(
                      "kat",
                      I18N_NOOP( "Kat" ),
                      version, description,
                      KAboutData::License_GPL_V2,
                      "(C) 2005 Roberto Cappuccio and the KAT team",
                      I18N_NOOP("A desktop search engine for KDE"),
                      "http://kat.sourceforge.net",
                      "robertoc@dnet.it"
                     );
    about.addAuthor( "Roberto Cappuccio", "Developer", "robertoc@dnet.it" );
    about.addAuthor( "Laurent Montel", "Developer", "montel@kde.org" );
    about.addAuthor( "Fred Schaettgen", "Developer", "kde.sch@ttgen.net" );
    about.addCredit( "Cavnar, W. B. and J. M. Trenkle", "N-Gram-Based Text Categorization\n"
                     "Third Annual Symposium on Document Analysis and Information Retrieval\n"
                     "Las Vegas, 11-13 April 1994\n"
                      "(Kat's language identification feature is based on this paper)" );
    about.setTranslator( I18N_NOOP("_: NAME OF TRANSLATORS\\nYour names") ,
                         I18N_NOOP("_: EMAIL OF TRANSLATORS\\nYour emails") );
    KCmdLineArgs::init( argc, argv, &about );
    KCmdLineArgs::addCmdLineOptions( options );

    KApplication app;

    KCmdLineArgs *args = KCmdLineArgs::parsedArgs();

    if ( app.isRestored() ) {
        RESTORE(DlgMainWindow);
    }
    else
    {
    	QGuardedPtr<KSplashScreen> splash;

    	QString appDataPath = locate( "data", "kat/kat_splash.png" );

    	QPixmap pixmap( appDataPath );

    	splash = new KSplashScreen( pixmap );

	// kill the splash after 2 seconds
	QTimer::singleShot( 2000, splash, SLOT(close()) );
	splash->show();
        splash->message( i18n("(C) 2005 - Roberto Cappuccio and the KAT team" ),
                         QTextEdit::AlignRight, QColor("white") );
        DlgMainWindow *mainWin = new DlgMainWindow();

        app.setMainWidget( mainWin );
        mainWin->show();

        if ( args->count()>=1 ) {
            //TODO for the moment load just one file
            mainWin->fileOpen( args->url(0) );

        }
    }

    args->clear();
    int returnVal = app.exec();
    return returnVal;
}

