/***************************************************************************
 *   Copyright (C) 2005 by Roberto Cappuccio                               *
 *   robertoc@dnet.it                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <kdebug.h>
#include <kglobal.h>
#include <qapplication.h>
#include <qtimer.h>
#include <qdir.h>

#include "kat.h"
#include "katcatalog.h"
#include "katscanfolder.h"

using namespace KIO;

KatScanFolder::KatScanFolder( const KURL& directory, KatCatalog* catalog,KatDatabaseManager *_dm )
    : KIO::Job( false ), m_catalog( catalog ), m_bAsync( true ), m_totalSize( 0L ), m_totalFiles( 0L ), m_totalSubdirs( 0L ), dm( _dm )
{
    startNextJob( directory );
}

void KatScanFolder::startNextJob( const KURL& url ) {
    m_lj = KIO::listRecursive( url, false );
    connect( m_lj, SIGNAL( entries( KIO::Job*, const KIO::UDSEntryList& ) ),
                      SLOT( slotEntries( KIO::Job*, const KIO::UDSEntryList& ) ) );
    this->addSubjob( m_lj );
}

void KatScanFolder::slotEntries( KIO::Job*, const KIO::UDSEntryList & list ) {
    static const QString& dot = KGlobal::staticQString( "." );
    static const QString& dotdot = KGlobal::staticQString( ".." );
    KIO::UDSEntryListConstIterator it = list.begin();
    KIO::UDSEntryListConstIterator end = list.end();

    QString path = m_catalog->getPath();

    dm->openTransaction();
    for (; it != end; ++it ) {
        KIO::UDSEntry::ConstIterator it2 = (*it).begin();
        KIO::filesize_t size = 0L;
        bool isLink = false;
        bool isDir = false;
        QString name;
        for( ; it2 != (*it).end(); it2++ ) {
            switch( (*it2).m_uds ) {
                case KIO::UDS_NAME:
                    name = (*it2).m_str;
                    break;
                case KIO::UDS_LINK_DEST:
                    isLink = !(*it2).m_str.isEmpty();
                    break;
                case KIO::UDS_SIZE:
                    size = ((*it2).m_long);
                    break;
                case KIO::UDS_FILE_TYPE:
                    isDir = S_ISDIR((*it2).m_long);
                    break;
                default:
                    break;
               }
        }
        if ( name == dot ) {
            m_totalSize += size;
        } else if ( name != dotdot ) {
            if ( !isLink ) {
                m_totalSize += size;
                m_catalog->setFileSize( m_totalSize );

                //kdDebug() << name << ":" << size << endl;

                KFileItem* kfi = new KFileItem( KFileItem::Unknown, // _mode
                                                KFileItem::Unknown, // _permissions
                                                KURL( path + "/" + name ), // url
                                                true // determineMimeTypeOnDemand
                                               );
                dm->saveFileRecord( kfi );
                delete kfi;
            }
            if ( !isDir ) {
                m_totalFiles++;
                m_catalog->setFiles( m_totalFiles );
            } else {
                m_totalSubdirs++;
                m_catalog->setFolders( m_totalSubdirs );
            }
        }
    }
    dm->commitTransaction();
}

KatScanFolder* KatScanFolder::scanFolderJob( const KURL& directory, KatCatalog* catalog, KatDatabaseManager * dm) {
    return new KatScanFolder( directory, catalog, dm );
}
/*
KIO::filesize_t KatScanFolder::scan( const KURL& directory, KatCatalog* catalog ) {
    KatScanFolder* scanFolder = scanFolderJob( directory, catalog );
    scanFolder->setSync();
    qApp->enter_loop();
    return ( scanFolder->totalSubdirs() + scanFolder->totalFiles() );
}
*/
void KatScanFolder::slotResult( KIO::Job* job ) {
    emit completed();
    if ( !m_bAsync ) {
        qApp->exit_loop();
    }
    KIO::Job::slotResult( job );
}

void KatScanFolder::slotScanAborted() {
    this->kill();
}

void KatScanFolder::virtual_hook( int id, void* data ) {
    KIO::Job::virtual_hook( id, data );
}

#include "katscanfolder.moc"
